@@ -5,6 +5,24 @@
 @CREATED    : June 2001 (Rick Hoge)
 @MODIFIED   : 
  * $Log: dcm2mnc.c,v $
+ * Revision 1.14.2.10  2005/08/18 18:17:36  bert
+ * Add -usecoordinates option
+ *
+ * Revision 1.14.2.9  2005/07/22 20:03:16  bert
+ * Minor change to consider sequence name when finding series boundaries
+ *
+ * Revision 1.14.2.8  2005/07/12 16:01:14  bert
+ * Sort on filename if all else fails
+ *
+ * Revision 1.14.2.7  2005/06/20 22:03:31  bert
+ * Add simple test for binary files to avoid choking on text files
+ *
+ * Revision 1.14.2.6  2005/06/09 20:48:36  bert
+ * Remove obsolete -descr option, add shiny new -fname and -dname options.  Also don't explicitly include math.h
+ *
+ * Revision 1.14.2.5  2005/06/02 18:35:32  bert
+ * Change version to 2.0.06
+ *
  * Revision 1.14.2.4  2005/05/16 22:39:56  bert
  * Insert conditionals to make the file build properly under Windows
  *
@@ -98,13 +116,12 @@
  *
 ---------------------------------------------------------------------------- */
 
-static const char rcsid[]="$Header: /software/source/minc/conversion/dcm2mnc/dcm2mnc.c,v 1.14.2.4 2005/05/16 22:39:56 bert Exp $";
+static const char rcsid[]="$Header: /software/source/minc/conversion/dcm2mnc/dcm2mnc.c,v 1.14.2.10 2005/08/18 18:17:36 bert Exp $";
 
 #define GLOBAL_ELEMENT_DEFINITION /* To define elements */
 #include "dcm2mnc.h"
 
 #include <sys/stat.h>
-#include <math.h>
 #if HAVE_DIRENT_H
 #include <dirent.h>
 #endif
@@ -124,7 +141,7 @@ static int check_file_type_consistency(int num_files, const char *file_list[]);
 
 struct globals G;
 
-#define VERSION_STRING "2.0.05 built " __DATE__ " " __TIME__
+#define VERSION_STRING "2.0.06 built " __DATE__ " " __TIME__
 
 #ifndef S_ISDIR
 #define S_ISDIR(x) (((x) & _S_IFMT) == _S_IFDIR)
@@ -142,8 +159,6 @@ ArgvInfo argTable[] = {
      "Print list of series (don't create files)"},
     {"-anon", ARGV_CONSTANT, (char *) TRUE, (char *) &G.Anon,
      "Exclude subject name from file header"},
-    {"-descr", ARGV_STRING, (char *) 1, (char *) &G.Name,
-     "Use <str> as session descriptor (default = patient initials)"},
 #if HAVE_POPEN
     {"-cmd", ARGV_STRING, (char *) 1, (char *) &G.command_line, 
      "Apply <command> to output files (e.g. gzip)"},
@@ -183,6 +198,23 @@ ArgvInfo argTable[] = {
      (char *)&G.use_stdin,
      "Read file list from standard input."},
 
+    {"-fname",
+     ARGV_STRING,
+     (char *)1,
+     (char *)&G.filename_format,
+     "Set format for output file name."},
+
+    {"-dname",
+     ARGV_STRING,
+     (char *)1,
+     (char *)&G.dirname_format,
+     "Set format for output directory name."},
+
+    {"-usecoordinates",
+     ARGV_CONSTANT,
+     (char *) TRUE,
+     (char *) &G.prefer_coords,
+     "Derive step value from coordinates rather than slice spacing."},
     {NULL, ARGV_END, NULL, NULL, NULL}
 
 };
@@ -206,8 +238,11 @@ main(int argc, char *argv[])
     G.splitDynScan = FALSE;     /* Don't split dynamic scans by default */
     G.splitEcho = TRUE;         /* Do split by echo by default */
     G.use_stdin = FALSE;        /* Do not read file list from stdin */
+    G.filename_format = NULL;
+    G.dirname_format = NULL;
 
     G.minc_history = time_stamp(argc, argv); /* Create minc history string */
+    G.prefer_coords = FALSE;
 
     G.pname = argv[0];          /* get program name */
     
@@ -248,7 +283,7 @@ main(int argc, char *argv[])
     /* Allocate the array of pointers used to implement the
      * list of filenames.
      */
-    file_list = malloc(num_file_args * sizeof(char *));
+    file_list = malloc(1 * sizeof(char *));
     CHKMEM(file_list);
 
     /* Go through the list of files, expanding directories where they
@@ -297,9 +332,11 @@ main(int argc, char *argv[])
             }
         }
         else {
+            file_list = realloc(file_list, (num_files + 1) * sizeof(char *));
             file_list[num_files++] = strdup(argv[ifile + 1]);
         }
 #else
+        file_list = realloc(file_list, (num_files + 1) * sizeof(char *));
         file_list[num_files++] = strdup(argv[ifile + 1]);
 #endif
     }
@@ -577,7 +614,11 @@ dcm_sort_function(const void *entry1, const void *entry2)
     else if (image1 > image2) return 1;
     else if (slice1 < slice2) return -1;
     else if (slice1 > slice2) return 1;
-    else return 0;
+
+    /* Last chance - if all else is equal, sort by the file names. 
+     */
+    else return strcmp((*file_info_list1)->file_name,
+                       (*file_info_list2)->file_name);
 }
 
 static void 
@@ -611,6 +652,7 @@ use_the_files(int num_files,
     int cur_dyn_scan_number;
     string_t cur_patient_name;
     string_t cur_patient_id;
+    string_t cur_sequence_name;
     int exit_status;
     char *output_file_name;
     string_t file_prefix;
@@ -691,6 +733,7 @@ use_the_files(int num_files,
 
                 strcpy(cur_patient_name, di_ptr[ifile]->patient_name);
                 strcpy(cur_patient_id, di_ptr[ifile]->patient_id);
+                strcpy(cur_sequence_name, di_ptr[ifile]->sequence_name);
 
                 used_file[ifile] = TRUE;
             }
@@ -706,7 +749,8 @@ use_the_files(int num_files,
                      (di_ptr[ifile]->dyn_scan_number == cur_dyn_scan_number ||
                       !G.splitDynScan) &&
                      !strcmp(cur_patient_name, di_ptr[ifile]->patient_name) &&
-                     !strcmp(cur_patient_id, di_ptr[ifile]->patient_id)) {
+                     !strcmp(cur_patient_id, di_ptr[ifile]->patient_id) &&
+                     !strcmp(cur_sequence_name, di_ptr[ifile]->sequence_name)) {
 
                 used_file[ifile] = TRUE;
             }
@@ -885,6 +929,41 @@ is_ima_file(const char *fullname)
     return (result);
 }
 
+/* _very_ limited test for "binary-ness" of a file.  This is just to keep
+ * text files and other junk present in a directory from screwing up our
+ * file type detection.
+ */
+static int
+is_binary_file(const char *fullname)
+{
+    FILE *fp;
+    int result = 0;
+    int i;
+
+    if ((fp = fopen(fullname, "rb")) == NULL) {
+        fprintf(stderr, "Error opening file %s!\n", fullname);
+    }
+    else {
+        /* This is an extremely trivial test for binary-ness.  Basically, we
+         * look at the first 512 bytes, and if there aren't lots of unprintable
+         * characters, we assume it is not a binary file.
+         */
+        for (i = 0; i < 128; i++) {
+            int cc = getc(fp);
+            if (cc == -1) {
+                result = 0;     /* too short!! */
+                break;
+            }
+            if (!isprint(cc) && cc != '\n' && cc != '\r') {
+                result++;
+            }
+        }
+        fclose(fp);
+    }
+    return (result > 3);        /* Binary if more than 3 unprintables */
+}
+
+
 static int
 check_file_type_consistency(int num_files, const char *file_list[])
 {
@@ -924,7 +1003,7 @@ check_file_type_consistency(int num_files, const char *file_list[])
                 return (-1);
             }
         }
-        else {
+        else if (is_binary_file(fn_ptr)) {
             if (G.file_type == UNDEF) {
                 G.file_type = N4DCM;
                 n4_offset = 0; 
