@@ -7,6 +7,18 @@
    @CREATED    : January 28, 1997 (Peter Neelin)
    @MODIFIED   : 
    * $Log: minc_file.c,v $
+   * Revision 1.6.2.7  2005/08/18 18:17:55  bert
+   * Fix up one warning message
+   *
+   * Revision 1.6.2.6  2005/07/22 20:02:45  bert
+   * 1) Save start value for time coordinate. 2) Don't append fractional seconds to time in filename
+   *
+   * Revision 1.6.2.5  2005/06/20 21:59:33  bert
+   * Add strfminc() to allow arbitrary output file naming, implement OPTS_NO_RESCALE debug option, fix rounding
+   *
+   * Revision 1.6.2.4  2005/06/02 18:20:06  bert
+   * Fix generation and scaling of files with signed data
+   *
    * Revision 1.6.2.3  2005/05/16 19:55:26  bert
    * Fix usage of G.Name
    *
@@ -110,17 +122,131 @@
    software for any purpose.  It is provided "as is" without
    express or implied warranty.
 ---------------------------------------------------------------------------- */
-static const char rcsid[] = "$Header: /software/source/minc/conversion/dcm2mnc/minc_file.c,v 1.6.2.3 2005/05/16 19:55:26 bert Exp $";
+static const char rcsid[] = "$Header: /software/source/minc/conversion/dcm2mnc/minc_file.c,v 1.6.2.7 2005/08/18 18:17:55 bert Exp $";
 
 #include "dcm2mnc.h"
 
 #include <sys/stat.h>
-#include <ctype.h>
 
 /* Define mri dimension names */
 static char *mri_dim_names[] = {
     NULL, "echo_time", MItime, "phase_number", "chemical_shift", NULL};
 
+int 
+strfminc(char *str_ptr, int str_max, const char *fmt_ptr, 
+         General_Info *gi_ptr)
+{
+    char *tmp_ptr;
+    int str_len = 0;
+    char scan_label[MRI_NDIMS][20];
+    Mri_Index imri;
+    static char *scan_prefix[MRI_NDIMS] = {"sl", "e", "d", "p", "cs"};
+    char tmp_str[1024];
+
+    /* Get strings for echo number, etc. 
+     */
+    for (imri = 0; imri < MRI_NDIMS; imri++) {
+        if ((gi_ptr->cur_size[imri] < gi_ptr->max_size[imri]) &&
+            (gi_ptr->cur_size[imri] == 1)) {
+            sprintf(scan_label[imri], "%s%d", 
+                    scan_prefix[imri],
+                    gi_ptr->default_index[imri]);
+        }
+        else {
+            strcpy(scan_label[imri], "");
+        }
+    }
+
+    while (*fmt_ptr != '\0') {
+        tmp_ptr = NULL;
+        if (*fmt_ptr == '%') {
+            fmt_ptr++;
+            switch (*fmt_ptr) {
+            case 'N':           /* Subject name */
+                string_to_filename(gi_ptr->patient.name,
+                                   tmp_str, sizeof(tmp_str));
+                if (tmp_str[0] == '\0') {
+                    tmp_ptr = "no_name";
+                }
+                else {
+                    tmp_ptr = tmp_str;
+                }
+                break;
+            case 'D':
+                string_to_filename(gi_ptr->patient.reg_date,
+                                   tmp_str, sizeof(tmp_str));
+                tmp_ptr = tmp_str;
+                break;
+            case 'S':
+                string_to_filename(gi_ptr->study.study_id,
+                                   tmp_str, sizeof(tmp_str));
+                tmp_ptr = tmp_str;
+                break;
+            case 'T':
+                strcpy(tmp_str, gi_ptr->patient.reg_time);
+                tmp_ptr = tmp_str;
+                while (*tmp_ptr != '\0') {
+                    if (!isdigit(*tmp_ptr)) {
+                        *tmp_ptr = '\0';
+                        break;
+                    }
+                    tmp_ptr++;
+                }
+                tmp_ptr = tmp_str;
+                break;
+            case 'A':
+                string_to_filename(gi_ptr->study.acquisition_id,
+                                   tmp_str, sizeof(tmp_str));
+                tmp_ptr = tmp_str;
+                break;
+            case 's':
+                tmp_ptr = scan_label[SLICE];
+                break;
+            case 'e':
+                tmp_ptr = scan_label[ECHO];
+                break;
+            case 't':
+                tmp_ptr = scan_label[TIME];
+                break;
+            case 'p':
+                tmp_ptr = scan_label[PHASE];
+                break;
+            case 'c':
+                tmp_ptr = scan_label[CHEM_SHIFT];
+                break;
+            case 'm':
+                if (!strcmp(gi_ptr->study.modality, MI_MRI)) {
+                    tmp_ptr = "_mri";
+                }
+                else if (!strcmp(gi_ptr->study.modality, MI_PET)) {
+                    tmp_ptr = "_pet";
+                }
+                else {
+                    tmp_ptr = "";
+                }
+                break;
+            default:
+                break;
+            }
+        }
+        if (tmp_ptr == NULL) {
+            if (str_len < str_max) {
+                *str_ptr++ = *fmt_ptr++;
+                str_len++;
+            }
+        }
+        else {
+            fmt_ptr++;
+            while (str_len < str_max && *tmp_ptr != '\0') {
+                *str_ptr++ = *tmp_ptr++;
+                str_len++;
+            }
+        }
+    }
+    *str_ptr++ = '\0';
+    return (str_len);
+}
+
 /* ----------------------------- MNI Header -----------------------------------
    @NAME       : create_minc_file
    @INPUT      : minc_file - name of file to create. If NULL, a name is 
@@ -141,7 +267,8 @@ static char *mri_dim_names[] = {
    CALLS       : 
    @CREATED    : November 26, 1993 (Peter Neelin)
    @MODIFIED   : rhoge - modified to create directory for session
-   ---------------------------------------------------------------------------- */
+ -------------------------------------------------------------------------- */
+
 int
 create_minc_file(const char *minc_file, 
                  int clobber,
@@ -150,20 +277,11 @@ create_minc_file(const char *minc_file,
                  char **output_file_name,
                  Loop_Type loop_type)
 {
-    static char temp_name[256];
-    char patient_name[256];
-    char reg_time[256];
-    char temp_str[256];
-    char suffix_str[256];
-    const char *filename;
+    char temp_name[1024];
+    char *filename;
     int minc_clobber;
     int mincid, icvid;
-    Mri_Index imri;
-    char scan_label[MRI_NDIMS][20];
-
-    /* added by rhoge for study directory, new naming conventions: */
-
-    char full_path[256];
+    static char full_path[1024];
 
     /* Prefixes for creating file name */
     static char *scan_prefix[MRI_NDIMS] = 
@@ -174,97 +292,50 @@ create_minc_file(const char *minc_file,
 
     /* Create the file name if needed */
     if (minc_file != NULL) {
-        filename = minc_file;
+        filename = (char *) minc_file;
     }
     else {
-        /* Get patient name */
-        /******************************************/
-        /* Changed by Leili from "string_to_initials" to "string_to_filename" */
-        /* based on people's request at MNI */ 
-        if (G.Name != NULL && *G.Name != '\0') {
-            strcpy(patient_name, G.Name);
-        } 
-        else {
-            string_to_filename(general_info->patient.name, patient_name,
-                               sizeof(patient_name));
-        }
-
-        if (strlen(patient_name) == 0) {
-            strcpy(patient_name, "no_name");
-        }
-
-        /******************************************/
-        /* Get Study Time */
-        string_to_filename(general_info->patient.reg_time, temp_str,
-                           sizeof(temp_str));
-        /* truncate to first 6 chars (hhmmss) */
-        strncpy(reg_time, temp_str, 6);
-        if (strlen(reg_time) == 0) {
-            strcpy(reg_time, "no_time");
-        }
-        reg_time[6]='\0'; /* terminate with null (strncpy does not) */
-
-        /* Get strings for echo number, etc. */
-        for (imri=0; imri < MRI_NDIMS; imri++) {
-            if ((general_info->cur_size[imri] < general_info->max_size[imri]) &&
-                (general_info->cur_size[imri] == 1)) {
-                sprintf(scan_label[imri], "%s%d", scan_prefix[imri],
-                        general_info->default_index[imri]);
-            }
-            else {
-                strcpy(scan_label[imri], "");
-            }
-        }
-
         /* rhoge:  add session directory to prefix */
       
         strcpy(full_path, file_prefix);
 
-        sprintf(temp_name, "%s_%s_%s/",
-                patient_name,
-                general_info->patient.reg_date,
-                reg_time);
+        if (G.dirname_format == NULL) {
+            G.dirname_format = "%N_%D_%T";
+        }
+        strfminc(temp_name, sizeof(temp_name), G.dirname_format, general_info);
         strcat(full_path, temp_name);
 
+        if (strlen(full_path) != 0) {
+            if (mkdir(full_path, 0777) && G.Debug) {
+                printf("Directory %s exists...\n", full_path);
+            }
+            strcat(full_path, "/");
+        }
 
         /* if measurement loop, make sure that acquisition_id is
-           a 6 digit (hhmmss) string with leading zero if needed */
-
+         * a 6 digit (hhmmss) string with leading zero if needed 
+         */
         if (loop_type == MEAS) {
-
             sprintf(general_info->study.acquisition_id, "%06d",
                     general_info->acq_id);
-
         }
 
         /* Create file name */
 
-        if (!strcmp(general_info->study.modality, MI_MRI)) {
-            strcpy(suffix_str, "_mri");
-        }
-        else if (!strcmp(general_info->study.modality, MI_PET)) {
-            strcpy(suffix_str, "_pet");
+        if (G.filename_format == NULL) {
+            G.filename_format = "%N_%D_%T_%A%s%e%t%p%c%m";
         }
+        strfminc(temp_name, sizeof(temp_name), G.filename_format,
+                 general_info);
 
-        sprintf(temp_name, "%s%s_%s_%s_%s%s%s%s%s%s%s.mnc", 
-                full_path,
-                patient_name,
-                general_info->patient.reg_date,
-                reg_time,
-                general_info->study.acquisition_id,
-                scan_label[SLICE],
-                scan_label[ECHO],
-                scan_label[TIME],
-                scan_label[PHASE],
-                scan_label[CHEM_SHIFT],
-                suffix_str);
-
-        filename = temp_name;
+        strcat(full_path, temp_name);
+        strcat(full_path, ".mnc"); /* Always append the extension */
+        filename = full_path;
 
         if (G.Debug) {
             printf("MINC file name:  %s\n", filename);
-            printf("File prefix:     %s\n", full_path);
-            printf("Patient name:    %s\n", patient_name);
+            printf("Patient name:    %s\n", 
+                   general_info->patient.name);
             printf("Study ID:        %s\n", 
                    general_info->study.study_id);
             printf("Acquisition ID:  %s\n", 
@@ -286,15 +357,9 @@ create_minc_file(const char *minc_file,
         }
     }
 
-    /* create the session directory if none exists */
-
-    if (mkdir(full_path, 0777) && G.Debug) {
-        printf("Directory %s exists...\n", full_path);
-    }
-
     /* Set output file name */
     if (output_file_name != NULL) {
-        *output_file_name = (char *) filename;
+        *output_file_name = filename;
     }
 
     /* Set the clobber value */
@@ -304,7 +369,7 @@ create_minc_file(const char *minc_file,
         minc_clobber = NC_NOCLOBBER;
 
     /* Create the file */
-    mincid = micreate((char *) filename, minc_clobber);
+    mincid = micreate(filename, minc_clobber);
     if (mincid == MI_ERROR) {
         return MI_ERROR;
     }
@@ -399,7 +464,7 @@ minc_set_spacing(int mincid, int varid, Mri_Index imri, General_Info *gi_ptr)
         avg = sum / length;     /* compute mean */
 
         if (step != 0.0 && avg != step) {
-            printf("WARNING: Sample width %f not equal to average delta %f\n",
+            printf("WARNING: Sample width (%g) not equal to average delta (%g)\n",
                    step, avg);
         }
 
@@ -444,6 +509,7 @@ minc_set_spacing(int mincid, int varid, Mri_Index imri, General_Info *gi_ptr)
      * The step should always equal the average spacing of the dimension.
      */
     miattputdbl(mincid, varid, MIstep, step);
+    miattputdbl(mincid, varid, MIstart, gi_ptr->coordinates[imri][0]);
 
     if (regular) {
         miattputstr(mincid, varid, MIspacing, MI_REGULAR);
@@ -668,7 +734,7 @@ void setup_minc_variables(int mincid, General_Info *general_info,
         miattputstr(mincid, varid, MIbirthdate, 
                     general_info->patient.birth_date);
     if (strlen(general_info->patient.age) > 0)
-        miattputstr(mincid, varid, "age", 
+        miattputstr(mincid, varid, MIage, 
                     general_info->patient.age);
     if (strlen(general_info->patient.sex) > 0)
         miattputstr(mincid, varid, MIsex, 
@@ -685,16 +751,16 @@ void setup_minc_variables(int mincid, General_Info *general_info,
         miattputstr(mincid, varid, "start_date", 
                     general_info->patient.reg_date);
     if (strlen(general_info->patient.reg_time) > 0)
-        miattputstr(mincid, varid, "start_time", 
+        miattputstr(mincid, varid, MIstart_time, 
                     general_info->patient.reg_time);
     if (strlen(general_info->study.modality) > 0)
         miattputstr(mincid, varid, MImodality, 
                     general_info->study.modality);
     if (strlen(general_info->study.manufacturer) > 0)
-        miattputstr(mincid, varid, "manufacturer", 
+        miattputstr(mincid, varid, MImanufacturer, 
                     general_info->study.manufacturer);
     if (strlen(general_info->study.model) > 0)
-        miattputstr(mincid, varid, "model", 
+        miattputstr(mincid, varid, MIdevice_model, 
                     general_info->study.model);
     if (general_info->study.field_value != -DBL_MAX)
         miattputdbl(mincid, varid, "field_value", 
@@ -722,7 +788,7 @@ void setup_minc_variables(int mincid, General_Info *general_info,
         miattputstr(mincid, varid, "performing_physician", 
                     general_info->study.referring_physician);
     if (strlen(general_info->study.operator) > 0)
-        miattputstr(mincid, varid, "operator", 
+        miattputstr(mincid, varid, MIoperator, 
                     general_info->study.operator);
 
     if (strlen(general_info->study.procedure) > 0)
@@ -746,7 +812,7 @@ void setup_minc_variables(int mincid, General_Info *general_info,
                     general_info->acq.scan_seq);
 
     if (strlen(general_info->acq.protocol_name) > 0)
-        miattputstr(mincid, varid, "protocol_name", 
+        miattputstr(mincid, varid, MIprotocol, 
                     general_info->acq.protocol_name);
     if (strlen(general_info->acq.receive_coil) > 0)
         miattputstr(mincid, varid, "receive_coil", 
@@ -921,9 +987,10 @@ void setup_minc_variables(int mincid, General_Info *general_info,
    @CREATED    : November 26, 1993 (Peter Neelin)
    @MODIFIED   :
    ---------------------------------------------------------------------------- */
+
 void
-save_minc_image(int icvid, General_Info *general_info, 
-                File_Info *file_info, Image_Data *image)
+save_minc_image(int icvid, General_Info *gi_ptr, 
+                File_Info *fi_ptr, Image_Data *image)
 {
     int mincid;
     long start[MAX_VAR_DIMS], count[MAX_VAR_DIMS];
@@ -931,7 +998,7 @@ save_minc_image(int icvid, General_Info *general_info,
     int idim;
     Mri_Index imri;
     char *dimname;
-    unsigned short pvalue, pmax, pmin;
+    int pvalue, pmax, pmin;
     double dvalue, maximum, minimum, scale, offset;
     long ipix, imagepix;
 
@@ -941,15 +1008,15 @@ save_minc_image(int icvid, General_Info *general_info,
     /* Create start and count variables */
     idim = 0;
     for (imri=MRI_NDIMS-1; (int) imri >= 0; imri--) {
-        if (general_info->image_index[imri] >= 0) {
-            file_index = general_info->image_index[imri];
-            if (general_info->cur_size[imri] > 1) {
-                array_index = search_list(file_info->index[imri], 
-                                          general_info->indices[imri],
-                                          general_info->cur_size[imri],
-                                          general_info->search_start[imri]);
+        if (gi_ptr->image_index[imri] >= 0) {
+            file_index = gi_ptr->image_index[imri];
+            if (gi_ptr->cur_size[imri] > 1) {
+                array_index = search_list(fi_ptr->index[imri], 
+                                          gi_ptr->indices[imri],
+                                          gi_ptr->cur_size[imri],
+                                          gi_ptr->search_start[imri]);
                 if (array_index < 0) array_index = 0;
-                general_info->search_start[imri] = array_index;
+                gi_ptr->search_start[imri] = array_index;
             }
             else {
                 array_index = 0;
@@ -961,30 +1028,30 @@ save_minc_image(int icvid, General_Info *general_info,
     }
     start[idim] = 0;
     start[idim+1] = 0;
-    count[idim] = general_info->nrows;
-    count[idim+1] = general_info->ncolumns;
+    count[idim] = gi_ptr->nrows;
+    count[idim+1] = gi_ptr->ncolumns;
 
     /* Write out slice position */
-    switch (general_info->slice_world) {
+    switch (gi_ptr->slice_world) {
     case XCOORD: dimname = MIxspace; break;
     case YCOORD: dimname = MIyspace; break;
     case ZCOORD: dimname = MIzspace; break;
     default: dimname = MIzspace;
     }
     mivarput1(mincid, ncvarid(mincid, dimname), 
-              &start[general_info->image_index[SLICE]], 
-              NC_DOUBLE, NULL, &file_info->coordinate[SLICE]);
+              &start[gi_ptr->image_index[SLICE]], 
+              NC_DOUBLE, NULL, &fi_ptr->coordinate[SLICE]);
 
     /* Write out time of slice, if needed */
-    if (general_info->cur_size[TIME] > 1) {
+    if (gi_ptr->cur_size[TIME] > 1) {
         mivarput1(mincid, ncvarid(mincid, mri_dim_names[TIME]), 
-                  &start[general_info->image_index[TIME]], 
-                  NC_DOUBLE, NULL, &file_info->coordinate[TIME]);
+                  &start[gi_ptr->image_index[TIME]], 
+                  NC_DOUBLE, NULL, &fi_ptr->coordinate[TIME]);
 
         /* If width information is present, save it to the appropriate
          * location in the time-width variable.
          */
-        if (file_info->width[TIME] != 0.0) {
+        if (fi_ptr->width[TIME] != 0.0) {
             int ncopts_prev;
             int varid;
 
@@ -1003,72 +1070,144 @@ save_minc_image(int icvid, General_Info *general_info,
              */
             if (varid >= 0) {
                 mivarput1(mincid, varid, 
-                          &start[general_info->image_index[TIME]], 
-                          NC_DOUBLE, NULL, &file_info->width[TIME]);
+                          &start[gi_ptr->image_index[TIME]], 
+                          NC_DOUBLE, NULL, &fi_ptr->width[TIME]);
             }
         }
     }
 
     /* Write out echo time of slice, if needed */
-    if (general_info->cur_size[ECHO] > 1) {
+    if (gi_ptr->cur_size[ECHO] > 1) {
         mivarput1(mincid, ncvarid(mincid, mri_dim_names[ECHO]), 
-                  &start[general_info->image_index[ECHO]], 
-                  NC_DOUBLE, NULL, &file_info->coordinate[ECHO]);
+                  &start[gi_ptr->image_index[ECHO]], 
+                  NC_DOUBLE, NULL, &fi_ptr->coordinate[ECHO]);
     }
 
-    /* Search image for max and min */
-    imagepix = general_info->nrows * general_info->ncolumns;
-    pmax = 0;
-    pmin = USHRT_MAX;
-    for (ipix=0; ipix < imagepix; ipix++) {
-        pvalue = image->data[ipix];
-        if (pvalue > pmax) pmax = pvalue;
-        if (pvalue < pmin) pmin = pvalue;
+    /* Search image for max and min.  This needs to be done such
+     * that we interpret signed data correctly, so there are separate
+     * loops for signed and unsigned data.
+     *
+     * If the data is signed, we need to search for the smallest and
+     * lowest 2's complement 16-bit values.  These will range from (at
+     * most) -32768 to 32767.  For unsigned values, we know that the
+     * range will be from 0 to 65535.  Since pmin, pmax, and pvalue
+     * are declared to be 'int', they will always be able to represent
+     * these values on 32-bit or 64-bit architectures.
+     *
+     * First, calculate the total number of voxels in this image.
+     */
+    imagepix = gi_ptr->nrows * gi_ptr->ncolumns;
+
+    pmax = INT_MIN;             /* Initialize to smallest possible int  */
+    pmin = INT_MAX;             /* Initialize to largest possible int */
+
+    if (gi_ptr->is_signed) {
+        short *ssh_ptr = (short *) image->data; /* Cast to signed data */
+
+        for (ipix = 0; ipix < imagepix; ipix++) {
+            pvalue = ssh_ptr[ipix];
+            if (pvalue > pmax)
+                pmax = pvalue;
+            if (pvalue < pmin) 
+                pmin = pvalue;
+        }
+    }
+    else {
+        unsigned short *ush_ptr = (unsigned short *) image->data;
+
+        for (ipix = 0; ipix < imagepix; ipix++) {
+            pvalue = ush_ptr[ipix];
+            if (pvalue > pmax)
+                pmax = pvalue;
+            if (pvalue < pmin) 
+                pmin = pvalue;
+        }
     }
 
-    /* Re-scale the images */
-    if (pmax > pmin)
-        scale = (general_info->pixel_max - general_info->pixel_min) /
+    /* Calculate the 'scale' and 'offset' (slope and intercept) we
+     * must use to scale the data.
+     */
+    if (pmax > pmin) {
+        scale = (gi_ptr->pixel_max - gi_ptr->pixel_min) / 
             ((double) pmax - (double) pmin);
-    else
+    }
+    else {
         scale = 0.0;
-
-    offset = general_info->pixel_min - scale * (double) pmin;
-    for (ipix=0; ipix < imagepix; ipix++) {
-        dvalue = image->data[ipix];
-        image->data[ipix] = dvalue * scale + offset;
     }
 
-    /* Calculate new intensity max and min */
-    if (general_info->pixel_max > general_info->pixel_min)
-        scale = (file_info->slice_max - file_info->slice_min) /
-            (general_info->pixel_max - general_info->pixel_min);
-    else
-        scale = 0.0;
+    offset = gi_ptr->pixel_min - scale * (double) pmin;
 
     /* debugging info for slice intensity scaling
      */
     if (G.Debug >= HI_LOGGING) {
-        printf("global range: %.2f %.2f  file range: %.2f %.2f pmax: %u\n",
-               general_info->pixel_min,
-               general_info->pixel_max,
-               file_info->slice_min,
-               file_info->slice_max,
-               pmax);
+        printf("ranges: global %.2f %.2f,  file %.2f %.2f, ",
+               gi_ptr->pixel_min,
+               gi_ptr->pixel_max,
+               fi_ptr->slice_min,
+               fi_ptr->slice_max);
+        printf("slice %d %d\n", pmin, pmax);
+        printf("1. scale %.2f offset %.2f\n", scale, offset);
     }
 
-    offset = file_info->slice_min - scale * general_info->pixel_min;
+    /* Re-scale the images. Again, this has to be done in a 
+     * "signedness-aware" way, so that negative values will be 
+     * dealt with properly in signed data.
+     */
+
+    if (gi_ptr->is_signed) {
+        short *ssh_ptr = (short *) image->data;
+
+        for (ipix = 0; ipix < imagepix; ipix++) {
+            dvalue = ssh_ptr[ipix];
+            ssh_ptr[ipix] = (short) rint(dvalue * scale + offset);
+        }
+    }
+    else {
+        unsigned short *ush_ptr = (unsigned short *) image->data;
+
+        for (ipix = 0; ipix < imagepix; ipix++) {
+            dvalue = ush_ptr[ipix];
+            ush_ptr[ipix] = (unsigned short) rint(dvalue * scale + offset);
+        }
+    }
+
+    if (gi_ptr->pixel_max > gi_ptr->pixel_min) {
+        scale = (fi_ptr->slice_max - fi_ptr->slice_min) /
+            (gi_ptr->pixel_max - gi_ptr->pixel_min);
+    }
+    else {
+        scale = 0.0;
+    }
+
+    offset = fi_ptr->slice_min - scale * gi_ptr->pixel_min;
     minimum = (double) pmin * scale + offset;
     maximum = (double) pmax * scale + offset;
 
+    if (G.Debug >= HI_LOGGING) {
+        printf("2. scale %.2f offset %.2f min %.2f max %.2f\n", scale, offset,
+               minimum, maximum);
+        printf("3. position %d,%d,%d\n", start[0], start[1], start[2]);
+    }
+
     /* Write out the max and min values */
     mivarput1(mincid, ncvarid(mincid, MIimagemin), start, NC_DOUBLE,
               NULL, &minimum);
     mivarput1(mincid, ncvarid(mincid, MIimagemax), start, NC_DOUBLE,
               NULL, &maximum);
 
-    /* Write out the image */
-    miicv_put(icvid, start, count, image->data);
+    if (G.opts & OPTS_NO_RESCALE) {
+        mivarput(mincid, 
+                 ncvarid(mincid, MIimage),
+                 start,
+                 count,
+                 NC_SHORT, 
+                 (gi_ptr->is_signed) ? MI_SIGNED : MI_UNSIGNED,
+                 image->data);
+    }
+    else {
+        /* Write out the image */
+        miicv_put(icvid, start, count, image->data);
+    }
 
     return;
 }
