@@ -34,6 +34,9 @@
 @CREATED    : July 27, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: image_conversion.c,v $
+ * Revision 6.10.2.1  2004/09/28 20:23:40  bert
+ * Minor portability fixes for Windows
+ *
  * Revision 6.10  2003/09/18 16:17:00  bert
  * Correctly cast double to nc_type
  *
@@ -147,24 +150,24 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/image_conversion.c,v 6.10 2003/09/18 16:17:00 bert Exp $ MINC (MNI)";
+static char rcsid[] = "$Header: /software/source/minc/libsrc/image_conversion.c,v 6.10.2.1 2004/09/28 20:23:40 bert Exp $ MINC (MNI)";
 #endif
 
-#include <type_limits.h>
-#include <minc_private.h>
+#include "minc_private.h"
+#include "type_limits.h"
 
 /* Private functions */
-private int MI_icv_get_type(mi_icv_type *icvp, int cdfid, int varid);
-private int MI_icv_get_vrange(mi_icv_type *icvp, int cdfid, int varid);
-private double MI_get_default_range(char *what, nc_type datatype, int sign);
-private int MI_icv_get_norm(mi_icv_type *icvp, int cdfid, int varid);
-private int MI_icv_access(int operation, mi_icv_type *icvp, long start[], 
+PRIVATE int MI_icv_get_type(mi_icv_type *icvp, int cdfid, int varid);
+PRIVATE int MI_icv_get_vrange(mi_icv_type *icvp, int cdfid, int varid);
+PRIVATE double MI_get_default_range(char *what, nc_type datatype, int sign);
+PRIVATE int MI_icv_get_norm(mi_icv_type *icvp, int cdfid, int varid);
+PRIVATE int MI_icv_access(int operation, mi_icv_type *icvp, long start[], 
                           long count[], void *values);
-private int MI_icv_zero_buffer(mi_icv_type *icvp, long count[], void *values);
-private int MI_icv_coords_tovar(mi_icv_type *icvp, 
+PRIVATE int MI_icv_zero_buffer(mi_icv_type *icvp, long count[], void *values);
+PRIVATE int MI_icv_coords_tovar(mi_icv_type *icvp, 
                                 long icv_start[], long icv_count[],
                                 long var_start[], long var_count[]);
-private int MI_icv_calc_scale(int operation, mi_icv_type *icvp, long coords[]);
+PRIVATE int MI_icv_calc_scale(int operation, mi_icv_type *icvp, long coords[]);
 
 /* Array of pointers to image conversion structures */
 static int minc_icv_list_nalloc = 0;
@@ -183,7 +186,7 @@ static mi_icv_type **minc_icv_list = NULL;
 @CREATED    : August 7, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_create()
+MNCAPI int miicv_create()
 {
    int new_icv;       /* Id of newly created icv */
    mi_icv_type *icvp;  /* Pointer to new icv structure */
@@ -296,7 +299,7 @@ public int miicv_create()
 @CREATED    : August 7, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_free(int icvid)
+MNCAPI int miicv_free(int icvid)
 {
    mi_icv_type *icvp;
 
@@ -336,7 +339,7 @@ public int miicv_free(int icvid)
 @CREATED    : August 7, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_setdbl(int icvid, int icv_property, double value)
+MNCAPI int miicv_setdbl(int icvid, int icv_property, double value)
 {
    int ival, idim;
    mi_icv_type *icvp;
@@ -457,7 +460,7 @@ public int miicv_setdbl(int icvid, int icv_property, double value)
 @MODIFIED   : January 22, 1993 (P.N.)
                  - modified handling of icv properties
 ---------------------------------------------------------------------------- */
-public int miicv_setint(int icvid, int icv_property, int value)
+MNCAPI int miicv_setint(int icvid, int icv_property, int value)
 {
 
    MI_SAVE_ROUTINE_NAME("miicv_setint");
@@ -483,7 +486,7 @@ public int miicv_setint(int icvid, int icv_property, int value)
 @CREATED    : January 22, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_setlong(int icvid, int icv_property, long value)
+MNCAPI int miicv_setlong(int icvid, int icv_property, long value)
 {
 
    MI_SAVE_ROUTINE_NAME("miicv_setlong");
@@ -509,7 +512,7 @@ public int miicv_setlong(int icvid, int icv_property, long value)
 @CREATED    : January 22, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_setstr(int icvid, int icv_property, char *value)
+MNCAPI int miicv_setstr(int icvid, int icv_property, char *value)
 {
    mi_icv_type *icvp;
 
@@ -599,7 +602,7 @@ public int miicv_setstr(int icvid, int icv_property, char *value)
 @CREATED    : January 22, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_inqdbl(int icvid, int icv_property, double *value)
+MNCAPI int miicv_inqdbl(int icvid, int icv_property, double *value)
 {
    int idim;
    mi_icv_type *icvp;
@@ -717,7 +720,7 @@ public int miicv_inqdbl(int icvid, int icv_property, double *value)
 @CREATED    : January 22, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_inqint(int icvid, int icv_property, int *value)
+MNCAPI int miicv_inqint(int icvid, int icv_property, int *value)
 {
    double dvalue;
 
@@ -742,7 +745,7 @@ public int miicv_inqint(int icvid, int icv_property, int *value)
 @CREATED    : January 22, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_inqlong(int icvid, int icv_property, long *value)
+MNCAPI int miicv_inqlong(int icvid, int icv_property, long *value)
 {
    double dvalue;
 
@@ -768,7 +771,7 @@ public int miicv_inqlong(int icvid, int icv_property, long *value)
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_inqstr(int icvid, int icv_property, char *value)
+MNCAPI int miicv_inqstr(int icvid, int icv_property, char *value)
 {
    mi_icv_type *icvp;
 
@@ -865,7 +868,7 @@ public int miicv_inqstr(int icvid, int icv_property, char *value)
 @CREATED    : September 9, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_ndattach(int icvid, int cdfid, int varid)
+MNCAPI int miicv_ndattach(int icvid, int cdfid, int varid)
 {
    mi_icv_type *icvp;         /* Pointer to icv structure */
    int idim;
@@ -951,7 +954,7 @@ public int miicv_ndattach(int icvid, int cdfid, int varid)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_get_type(mi_icv_type *icvp, int cdfid, int varid)
+PRIVATE int MI_icv_get_type(mi_icv_type *icvp, int cdfid, int varid)
 {
    int oldncopts;            /* For saving value of ncopts */
    char stringa[MI_MAX_ATTSTR_LEN];
@@ -996,7 +999,7 @@ private int MI_icv_get_type(mi_icv_type *icvp, int cdfid, int varid)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_get_vrange(mi_icv_type *icvp, int cdfid, int varid)
+PRIVATE int MI_icv_get_vrange(mi_icv_type *icvp, int cdfid, int varid)
 {
    double vrange[2];         /* Valid range buffer */
 
@@ -1027,7 +1030,7 @@ private int MI_icv_get_vrange(mi_icv_type *icvp, int cdfid, int varid)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private double MI_get_default_range(char *what, nc_type datatype, int sign)
+PRIVATE double MI_get_default_range(char *what, nc_type datatype, int sign)
 {
    double range[2];
 
@@ -1063,7 +1066,7 @@ private double MI_get_default_range(char *what, nc_type datatype, int sign)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_get_norm(mi_icv_type *icvp, int cdfid, int varid)
+PRIVATE int MI_icv_get_norm(mi_icv_type *icvp, int cdfid, int varid)
      /* ARGSUSED */
 {
    int oldncopts;             /* For saving value of ncopts */
@@ -1147,7 +1150,7 @@ private int MI_icv_get_norm(mi_icv_type *icvp, int cdfid, int varid)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_detach(int icvid)
+MNCAPI int miicv_detach(int icvid)
 {
    mi_icv_type *icvp;
    int idim;
@@ -1195,7 +1198,7 @@ public int miicv_detach(int icvid)
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_get(int icvid, long start[], long count[], void *values)
+MNCAPI int miicv_get(int icvid, long start[], long count[], void *values)
 {
    mi_icv_type *icvp;
 
@@ -1226,7 +1229,7 @@ public int miicv_get(int icvid, long start[], long count[], void *values)
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miicv_put(int icvid, long start[], long count[], void *values)
+MNCAPI int miicv_put(int icvid, long start[], long count[], void *values)
 {
    mi_icv_type *icvp;
 
@@ -1257,7 +1260,7 @@ public int miicv_put(int icvid, long start[], long count[], void *values)
 @CREATED    : August 11, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_access(int operation, mi_icv_type *icvp, long start[], 
+PRIVATE int MI_icv_access(int operation, mi_icv_type *icvp, long start[], 
                           long count[], void *values)
 {
    int *bufsize_step;                /* Pointer to array giving increments
@@ -1381,7 +1384,7 @@ private int MI_icv_access(int operation, mi_icv_type *icvp, long start[],
 @CREATED    : September 9, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_zero_buffer(mi_icv_type *icvp, long count[], void *values)
+PRIVATE int MI_icv_zero_buffer(mi_icv_type *icvp, long count[], void *values)
 {
    double zeroval, zerobuf;
    void *zerostart;
@@ -1437,7 +1440,7 @@ private int MI_icv_zero_buffer(mi_icv_type *icvp, long count[], void *values)
 @CREATED    : September 1, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_coords_tovar(mi_icv_type *icvp, 
+PRIVATE int MI_icv_coords_tovar(mi_icv_type *icvp, 
                                 long icv_start[], long icv_count[],
                                 long var_start[], long var_count[])
 {
@@ -1540,7 +1543,7 @@ private int MI_icv_coords_tovar(mi_icv_type *icvp,
 @CREATED    : August 10, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_icv_calc_scale(int operation, mi_icv_type *icvp, long coords[])
+PRIVATE int MI_icv_calc_scale(int operation, mi_icv_type *icvp, long coords[])
 {
    long mmcoords[MAX_VAR_DIMS];   /* Coordinates for max/min variable */
    double usr_imgmax, usr_imgmin;
@@ -1727,7 +1730,7 @@ private int MI_icv_calc_scale(int operation, mi_icv_type *icvp, long coords[])
 @CREATED    : August 7, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-semiprivate mi_icv_type *MI_icv_chkid(int icvid)
+SEMIPRIVATE mi_icv_type *MI_icv_chkid(int icvid)
 {
    MI_SAVE_ROUTINE_NAME("MI_icv_chkid");
 
