@@ -10,6 +10,12 @@
 @CREATED    : April 28, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincaverage.c,v $
+ * Revision 6.4.2.2  2005/03/16 19:02:49  bert
+ * Port changes from 2.0 branch
+ *
+ * Revision 6.4.2.1  2004/09/28 20:22:12  bert
+ * Minor portability fix for Windows
+ *
  * Revision 6.4  2001/04/24 13:38:42  neelin
  * Replaced NC_NAT with MI_ORIGINAL_TYPE.
  *
@@ -65,9 +71,10 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincaverage/mincaverage.c,v 6.4 2001/04/24 13:38:42 neelin Exp $";
+static char rcsid[]="$Header: /software/source/minc/progs/mincaverage/mincaverage.c,v 6.4.2.2 2005/03/16 19:02:49 bert Exp $";
 #endif
 
+#include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -78,15 +85,10 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincavera
 #include <minc.h>
 #include <ParseArgv.h>
 #include <time_stamp.h>
-#include <minc_def.h>
 #include <voxel_loop.h>
 
 /* Constants */
 
-#ifndef public
-#  define public
-#endif
-
 #ifndef TRUE
 #  define TRUE 1
 #  define FALSE 0
@@ -122,30 +124,29 @@ typedef struct {
 } Norm_Data;
 
 /* Function prototypes */
-public int main(int argc, char *argv[]);
-public void do_normalization(void *caller_data, long num_voxels, 
+static void do_normalization(void *caller_data, long num_voxels, 
                              int input_num_buffers, int input_vector_length,
                              double *input_data[],
                              int output_num_buffers, int output_vector_length,
                              double *output_data[],
                              Loop_Info *loop_info);
-public void find_mincfile_range(int mincid, double *minimum, double *maximum);
-public void do_average(void *caller_data, long num_voxels, 
+static void find_mincfile_range(int mincid, double *minimum, double *maximum);
+static void do_average(void *caller_data, long num_voxels, 
                        int input_num_buffers, int input_vector_length,
                        double *input_data[],
                        int output_num_buffers, int output_vector_length,
                        double *output_data[],
                        Loop_Info *loop_info);
-public void start_average(void *caller_data, long num_voxels, 
+static void start_average(void *caller_data, long num_voxels, 
                           int output_num_buffers, int output_vector_length,
                           double *output_data[],
                           Loop_Info *loop_info);
-public void finish_average(void *caller_data, long num_voxels, 
+static void finish_average(void *caller_data, long num_voxels, 
                           int output_num_buffers, int output_vector_length,
                           double *output_data[],
                           Loop_Info *loop_info);
-public int get_double_list(char *dst, char *key, char *nextarg);
-public char **read_file_names(char *filelist, int *num_files);
+static int get_double_list(char *dst, char *key, char *nextarg);
+static char **read_file_names(char *filelist, int *num_files);
 
 /* Argument variables */
 int clobber = FALSE;
@@ -242,7 +243,7 @@ ArgvInfo argTable[] = {
 
 /* Main program */
 
-public int main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
    char **infiles, *outfiles[2];
    int nfiles, nout;
@@ -357,12 +358,12 @@ public int main(int argc, char *argv[])
       /* Save the weights */
       average_data.num_weights = weights.numvalues;
       average_data.weights = 
-         MALLOC(sizeof(*average_data.weights) * average_data.num_weights);
+         malloc(sizeof(*average_data.weights) * average_data.num_weights);
       for (iweight=0; iweight < average_data.num_weights; iweight++) {
          average_data.weights[iweight] = weights.values[iweight];
       }
 
-      FREE(weights.values);
+      free(weights.values);
    }
 
    /* Check for width weighting */
@@ -410,7 +411,7 @@ public int main(int argc, char *argv[])
          (void) ncdiminq(first_mincid, dim[0], NULL, &count);
          average_data.num_weights = count;
          average_data.weights = 
-            MALLOC(sizeof(*average_data.weights) * average_data.num_weights);
+            malloc(sizeof(*average_data.weights) * average_data.num_weights);
 
          /* Read in the widths */
          start = 0;
@@ -474,9 +475,9 @@ public int main(int argc, char *argv[])
 
    /* Do normalization if needed */
    average_data.norm_factor = 
-      MALLOC(sizeof(*average_data.norm_factor) * nfiles);
+      malloc(sizeof(*average_data.norm_factor) * nfiles);
    if (normalize) {
-      vol_mean = MALLOC(sizeof(*vol_mean) * nfiles);
+      vol_mean = malloc(sizeof(*vol_mean) * nfiles);
       loop_options = create_loop_options();
       set_loop_verbose(loop_options, FALSE);
       set_loop_accumulate(loop_options, TRUE, 0, NULL, NULL);
@@ -534,7 +535,7 @@ public int main(int argc, char *argv[])
                            ifile, average_data.norm_factor[ifile]);
          }
       }
-      FREE(vol_mean);
+      free(vol_mean);
    }
    else {
       for (ifile=0; ifile < nfiles; ifile++) {
@@ -563,8 +564,8 @@ public int main(int argc, char *argv[])
    free_loop_options(loop_options);
 
    /* Free stuff */
-   FREE(average_data.weights);
-   FREE(average_data.norm_factor);
+   free(average_data.weights);
+   free(average_data.norm_factor);
 
    exit(EXIT_SUCCESS);
 }
@@ -582,7 +583,7 @@ public int main(int argc, char *argv[])
 @CREATED    : April 25, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void do_normalization(void *caller_data, long num_voxels, 
+static void do_normalization(void *caller_data, long num_voxels, 
                              int input_num_buffers, int input_vector_length,
                              double *input_data[],
                              int output_num_buffers, int output_vector_length,
@@ -636,7 +637,7 @@ public void do_normalization(void *caller_data, long num_voxels,
 @CREATED    : April 25, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void find_mincfile_range(int mincid, double *minimum, double *maximum)
+static void find_mincfile_range(int mincid, double *minimum, double *maximum)
 {
    int varid;
    char *varname;
@@ -711,7 +712,7 @@ public void find_mincfile_range(int mincid, double *minimum, double *maximum)
 @CREATED    : April 25, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void do_average(void *caller_data, long num_voxels, 
+static void do_average(void *caller_data, long num_voxels, 
                        int input_num_buffers, int input_vector_length,
                        double *input_data[],
                        int output_num_buffers, int output_vector_length,
@@ -795,7 +796,7 @@ public void do_average(void *caller_data, long num_voxels,
 @CREATED    : April 25, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void start_average(void *caller_data, long num_voxels, 
+static void start_average(void *caller_data, long num_voxels, 
                           int output_num_buffers, int output_vector_length,
                           double *output_data[],
                           Loop_Info *loop_info)
@@ -838,7 +839,7 @@ public void start_average(void *caller_data, long num_voxels,
 @CREATED    : April 25, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void finish_average(void *caller_data, long num_voxels, 
+static void finish_average(void *caller_data, long num_voxels, 
                           int output_num_buffers, int output_vector_length,
                           double *output_data[],
                           Loop_Info *loop_info)
@@ -905,7 +906,7 @@ public void finish_average(void *caller_data, long num_voxels,
 @CREATED    : March 8, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_double_list(char *dst, char *key, char *nextarg)
+static int get_double_list(char *dst, char *key, char *nextarg)
 {
 #define VECTOR_SEPARATOR ','
 
@@ -954,11 +955,11 @@ public int get_double_list(char *dst, char *key, char *nextarg)
          num_alloc += 20;
          if (double_list == NULL) {
             double_list = 
-               MALLOC(num_alloc * sizeof(*double_list));
+               malloc(num_alloc * sizeof(*double_list));
          }
          else {
             double_list = 
-               REALLOC(double_list, num_alloc * sizeof(*double_list));
+               realloc(double_list, num_alloc * sizeof(*double_list));
          }
       }
       double_list[num_elements-1] = dvalue;
@@ -974,7 +975,7 @@ public int get_double_list(char *dst, char *key, char *nextarg)
    /* Update the global variables */
    double_array->numvalues = num_elements;
    if (double_array->values != NULL) {
-      FREE(double_array->values);
+      free(double_array->values);
    }
    double_array->values = double_list;
 
@@ -996,7 +997,7 @@ public int get_double_list(char *dst, char *key, char *nextarg)
 @CREATED    : March 8, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public char **read_file_names(char *filelist, int *num_files)
+static char **read_file_names(char *filelist, int *num_files)
 {
 #define FILE_NAME_ALLOC_SIZE 10
    char **files;
@@ -1020,7 +1021,7 @@ public char **read_file_names(char *filelist, int *num_files)
 
    /* Allocate an initial array and NULL-terminate it */
    array_size = FILE_NAME_ALLOC_SIZE;
-   files = MALLOC(sizeof(*files) * array_size);
+   files = malloc(sizeof(*files) * array_size);
    if (files == NULL) {
       (void) fprintf(stderr, "Error allocating memory\n");
       return NULL;
@@ -1042,7 +1043,7 @@ public char **read_file_names(char *filelist, int *num_files)
       /* Make room for names if needed */
       while (nfiles >= array_size-1) {
          array_size += FILE_NAME_ALLOC_SIZE;
-         files = REALLOC(files, sizeof(*files) * array_size);
+         files = realloc(files, sizeof(*files) * array_size);
          if (files == NULL) {
             (void) fprintf(stderr, "Error allocating memory\n");
             return NULL;
