@@ -10,6 +10,12 @@
 @CREATED    : August 7, 1997 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincmakescalar.c,v $
+ * Revision 6.3.2.2  2005/03/16 19:02:51  bert
+ * Port changes from 2.0 branch
+ *
+ * Revision 6.3.2.1  2005/01/25 21:01:52  bert
+ * Check for proper placement of vector_dimension
+ *
  * Revision 6.3  2001/04/24 13:38:43  neelin
  * Replaced NC_NAT with MI_ORIGINAL_TYPE.
  *
@@ -37,7 +43,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincmakescalar/mincmakescalar.c,v 6.3 2001/04/24 13:38:43 neelin Exp $";
+static char rcsid[]="$Header: /software/source/minc/progs/mincmakescalar/mincmakescalar.c,v 6.3.2.2 2005/03/16 19:02:51 bert Exp $";
 #endif
 
 #include <stdlib.h>
@@ -49,13 +55,8 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincmakes
 #include <minc.h>
 #include <ParseArgv.h>
 #include <time_stamp.h>
-#include <minc_def.h>
 #include <voxel_loop.h>
 
-#ifndef public
-#  define public
-#endif
-
 #ifndef TRUE
 #  define TRUE 1
 #  define FALSE 0
@@ -84,13 +85,13 @@ typedef struct {
 } Program_Data;
 
 /* Function prototypes */
-public void do_makescalar(void *caller_data, long num_voxels,
+static void do_makescalar(void *caller_data, long num_voxels,
                           int input_num_buffers, int input_vector_length,
                           double *input_data[],
                           int output_num_buffers, int output_vector_length,
                           double *output_data[], Loop_Info *loop_info);
-public int get_double_list(char *dst, char *key, char *nextarg);
-public long get_vector_length(int mincid);
+static int get_double_list(char *dst, char *key, char *nextarg);
+static long get_vector_length(int mincid);
 
 /* Argument variables */
 int clobber = FALSE;
@@ -150,6 +151,13 @@ ArgvInfo argTable[] = {
    {NULL, ARGV_END, NULL, NULL, NULL}
 };
 
+const char str_wrong_dimension_order[] = {
+    "Your input file contains an image with a vector dimension, but the\n"
+    "vector dimension isn't the last (i.e. fastest-varying) dimension in\n"
+    "the image. Please restructure the file using mincreshape before\n"
+    "attempting to use mincmakescalar.\n"
+};
+
 /* Main program */
 
 int main(int argc, char *argv[])
@@ -196,7 +204,7 @@ int main(int argc, char *argv[])
       program_data.conversion_type = conversion_type;
       program_data.num_coefficients = linear_coefficients.numvalues;
       program_data.linear_coefficients = 
-         MALLOC(linear_coefficients.numvalues * 
+         malloc(linear_coefficients.numvalues * 
                 sizeof(*program_data.linear_coefficients));
       for (ivalue=0; ivalue < linear_coefficients.numvalues; ivalue++) {
          program_data.linear_coefficients[ivalue] =
@@ -207,6 +215,10 @@ int main(int argc, char *argv[])
    /* Open the input file and get the vector length */
    inmincid = miopen(infile, NC_NOWRITE);
    input_vector_length = get_vector_length(inmincid);
+   if (input_vector_length < 0) {
+       fprintf(stderr, str_wrong_dimension_order);
+       exit(EXIT_FAILURE);
+   }
    if (input_vector_length < 1) input_vector_length = 1;
 
    /* Check that this length is okay */
@@ -239,10 +251,10 @@ int main(int argc, char *argv[])
 
    /* Free stuff */
    if (program_data.linear_coefficients != NULL) {
-      FREE(program_data.linear_coefficients);
+      free(program_data.linear_coefficients);
    }
    if (linear_coefficients.values != NULL) {
-      FREE(linear_coefficients.values);
+      free(linear_coefficients.values);
    }
 
    exit(EXIT_SUCCESS);
@@ -269,7 +281,7 @@ int main(int argc, char *argv[])
 @CREATED    : August 7, 1997 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void do_makescalar(void *caller_data, long num_voxels,
+static void do_makescalar(void *caller_data, long num_voxels,
                           int input_num_buffers, int input_vector_length,
                           double *input_data[],
                           int output_num_buffers, int output_vector_length,
@@ -373,7 +385,7 @@ public void do_makescalar(void *caller_data, long num_voxels,
 @CREATED    : March 8, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_double_list(char *dst, char *key, char *nextarg)
+static int get_double_list(char *dst, char *key, char *nextarg)
 {
 #define VECTOR_SEPARATOR ','
 
@@ -422,11 +434,11 @@ public int get_double_list(char *dst, char *key, char *nextarg)
          num_alloc += 20;
          if (double_list == NULL) {
             double_list = 
-               MALLOC(num_alloc * sizeof(*double_list));
+               malloc(num_alloc * sizeof(*double_list));
          }
          else {
             double_list = 
-               REALLOC(double_list, num_alloc * sizeof(*double_list));
+               realloc(double_list, num_alloc * sizeof(*double_list));
          }
       }
       double_list[num_elements-1] = dvalue;
@@ -442,7 +454,7 @@ public int get_double_list(char *dst, char *key, char *nextarg)
    /* Update the global variables */
    double_array->numvalues = num_elements;
    if (double_array->values != NULL) {
-      FREE(double_array->values);
+      free(double_array->values);
    }
    double_array->values = double_list;
 
@@ -461,13 +473,14 @@ public int get_double_list(char *dst, char *key, char *nextarg)
 @CREATED    : November 30, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public long get_vector_length(int mincid)
+static long get_vector_length(int mincid)
 {
    int imgid;
    int ndims;
    int dim[MAX_VAR_DIMS];
    char dimname[MAX_NC_NAME];
    long vector_length;
+   int i;
 
    /* Get image variable id */
    imgid = ncvarid(mincid, MIimage);
@@ -479,6 +492,17 @@ public long get_vector_length(int mincid)
    (void) ncdiminq(mincid, dim[ndims-1], dimname, &vector_length);
    if ((strcmp(dimname, MIvector_dimension) != 0) || (ndims <= 2)) {
       vector_length = 0;
+
+      /* New deal - check for an actual vector_dimension anywhere in the
+       * file.
+       */
+      for (i = 0; i < ndims; i++) {
+          ncdiminq(mincid, dim[i], dimname, NULL);
+          if (!strcmp(dimname, MIvector_dimension)) {
+              vector_length = -1;
+              break;
+          }
+      }
    }
 
    return vector_length;
