@@ -6,6 +6,12 @@
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: resample_volumes.c,v $
+ * Revision 6.3.2.2  2005/07/13 19:34:48  bert
+ * Implemented sinc interpolant
+ *
+ * Revision 6.3.2.1  2005/03/16 19:02:51  bert
+ * Port changes from 2.0 branch
+ *
  * Revision 6.3  2001/08/16 13:32:39  neelin
  * Partial fix for valid_range of different type from image (problems
  * arising from double to float conversion/rounding). NOT COMPLETE.
@@ -84,7 +90,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincresample/resample_volumes.c,v 6.3 2001/08/16 13:32:39 neelin Exp $";
+static char rcsid[]="$Header: /software/source/minc/progs/mincresample/resample_volumes.c,v 6.3.2.2 2005/07/13 19:34:48 bert Exp $";
 #endif
 
 #include <stdlib.h>
@@ -94,7 +100,6 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincresam
 #include <math.h>
 #include <minc.h>
 #include <volume_io.h>
-#include <minc_def.h>
 #include "mincresample.h"
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -113,9 +118,9 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincresam
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void resample_volumes(Program_Flags *program_flags,
-                             VVolume *in_vol, VVolume *out_vol, 
-                             General_transform *transformation)
+void resample_volumes(Program_Flags *program_flags,
+                      VVolume *in_vol, VVolume *out_vol, 
+                      General_transform *transformation)
 {
    long in_start[MAX_VAR_DIMS], in_count[MAX_VAR_DIMS], in_end[MAX_VAR_DIMS];
    long out_start[MAX_VAR_DIMS], out_count[MAX_VAR_DIMS];
@@ -132,9 +137,9 @@ public void resample_volumes(Program_Flags *program_flags,
 
    /* Allocate slice min/max arrays if needed */
    if (ofp->do_slice_renormalization) {
-      slice_min = MALLOC(ofp->images_per_file * ofp->slices_per_image *
+      slice_min = malloc(ofp->images_per_file * ofp->slices_per_image *
                          sizeof(double));
-      slice_max = MALLOC(ofp->images_per_file * ofp->slices_per_image *
+      slice_max = malloc(ofp->images_per_file * ofp->slices_per_image *
                          sizeof(double));
    }
 
@@ -264,8 +269,8 @@ public void resample_volumes(Program_Flags *program_flags,
    /* Recompute slices and free vectors, if needed */
    if (ofp->do_slice_renormalization) {
       renormalize_slices(program_flags, out_vol, slice_min, slice_max);
-      FREE(slice_min);
-      FREE(slice_max);
+      free(slice_min);
+      free(slice_max);
    }
 
 }
@@ -285,8 +290,8 @@ public void resample_volumes(Program_Flags *program_flags,
 @CREATED    : February 10, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void load_volume(File_Info *file, long start[], long count[], 
-                        Volume_Data *volume)
+void load_volume(File_Info *file, long start[], long count[], 
+                 Volume_Data *volume)
 {
    long nread, islice, mm_start[MAX_VAR_DIMS], mm_count[MAX_VAR_DIMS];
    int varid, ivar, idim, ndims;
@@ -420,9 +425,9 @@ public void load_volume(File_Info *file, long start[], long count[],
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void get_slice(long slice_num, VVolume *in_vol, VVolume *out_vol, 
-                      General_transform *transformation, 
-                      double *minimum, double *maximum)
+void get_slice(long slice_num, VVolume *in_vol, VVolume *out_vol, 
+               General_transform *transformation, 
+               double *minimum, double *maximum)
 {
    Slice_Data *slice;
    Volume_Data *volume;
@@ -541,8 +546,8 @@ public void get_slice(long slice_num, VVolume *in_vol, VVolume *out_vol,
 @CREATED    : February 10, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int trilinear_interpolant(Volume_Data *volume, 
-                                 Coord_Vector coord, double *result)
+int trilinear_interpolant(Volume_Data *volume, 
+                          Coord_Vector coord, double *result)
 {
    long slcind, rowind, colind, slcmax, rowmax, colmax;
    long slcnext, rownext, colnext;
@@ -658,8 +663,8 @@ public int trilinear_interpolant(Volume_Data *volume,
 @CREATED    : February 12, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int tricubic_interpolant(Volume_Data *volume, 
-                                Coord_Vector coord, double *result)
+int tricubic_interpolant(Volume_Data *volume, 
+                         Coord_Vector coord, double *result)
 {
    long slcind, rowind, colind, slcmax, rowmax, colmax, index[VOL_NDIMS];
    double frac[VOL_NDIMS];
@@ -716,9 +721,9 @@ public int tricubic_interpolant(Volume_Data *volume,
 @CREATED    : February 12, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int do_Ncubic_interpolation(Volume_Data *volume, 
-                                   long index[], int cur_dim, 
-                                   double frac[], double *result)
+int do_Ncubic_interpolation(Volume_Data *volume, 
+                            long index[], int cur_dim, 
+                            double frac[], double *result)
 {
    long base_index;
    double v0, v1, v2, v3, u;
@@ -801,6 +806,412 @@ public int do_Ncubic_interpolation(Volume_Data *volume,
    return TRUE;
 }
 
+/************************************************************************
+ * Windowed Sinc Interpolant
+ *  
+ * The technique used is borrowed from Neil Thacker et al., "Improved
+ * Quality of Re-sliced MR Images Using Re-normalized Sinc
+ * Interpolation", Journal of Magnetic Resonance Imaging 10:582-588
+ * (1999).
+ *
+ * Any bugs are of course my own fault!
+ *
+ *     -bert
+ */
+
+int sinc_half_width = SINC_HALF_WIDTH_MAX / 2;
+
+enum sinc_interpolant_window_t sinc_window_type = SINC_WINDOW_HANNING;
+
+/* basic windowed sinc function */
+
+static double 
+windowed_sinc(double delta)
+{
+    double phase;
+    double sinc;
+    double window;
+
+    /* Calculate the sinc function. 
+     */
+    phase = delta * M_PI;
+
+    if (phase == 0.0) {
+        sinc = 1.0;
+    }
+    else {
+        sinc = sin(phase) / phase;
+    }
+
+    switch (sinc_window_type) {
+    case SINC_WINDOW_HANNING:
+        /* Calculate the Hanning window.
+         */
+        window = 0.50 + 0.50 * cos(phase / (1.0 + sinc_half_width));
+        break;
+
+    case SINC_WINDOW_HAMMING:
+        /* Calculate the Hamming window.
+         */
+        window = 0.54 + 0.46 * cos(phase / (1.0 + sinc_half_width));
+        break;
+
+    default:
+        window = 1.0;           /* No window */
+        break;
+    }
+    return (sinc * window);
+}
+
+/* Floating-point (unscaled) multiply/accumulate operations */
+#define SINC_FRND result += *pix_ptr++ * *win_ptr++
+
+/* Unroll those loops!! */     
+#define SINC_FMAC \
+    result = 0.0; \
+    switch (sinc_half_width) { \
+    case 10: SINC_FRND; SINC_FRND; \
+    case 9:  SINC_FRND; SINC_FRND; \
+    case 8:  SINC_FRND; SINC_FRND; \
+    case 7:  SINC_FRND; SINC_FRND; \
+    case 6:  SINC_FRND; SINC_FRND; \
+    case 5:  SINC_FRND; SINC_FRND; \
+    case 4:  SINC_FRND; SINC_FRND; \
+    case 3:  SINC_FRND; SINC_FRND; \
+    case 2:  SINC_FRND; SINC_FRND; \
+    case 1:  SINC_FRND; SINC_FRND; \
+    SINC_FRND; /* Do the leftover */ \
+    }
+
+/* Integer (scaled) multiply/accumulate operations */
+#define SINC_IRND result += ((slope * *pix_ptr++) + intercept) * *win_ptr++
+
+/* Unroll the loops!! */
+#define SINC_IMAC \
+    result = 0.0; \
+    switch (sinc_half_width) { \
+    case 10: SINC_IRND; SINC_IRND; \
+    case 9:  SINC_IRND; SINC_IRND; \
+    case 8:  SINC_IRND; SINC_IRND; \
+    case 7:  SINC_IRND; SINC_IRND; \
+    case 6:  SINC_IRND; SINC_IRND; \
+    case 5:  SINC_IRND; SINC_IRND; \
+    case 4:  SINC_IRND; SINC_IRND; \
+    case 3:  SINC_IRND; SINC_IRND; \
+    case 2:  SINC_IRND; SINC_IRND; \
+    case 1:  SINC_IRND; SINC_IRND; \
+    SINC_IRND; /* Do the leftover */ \
+    }
+
+static double 
+sinc_mac_d(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    long offset;
+    double *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (double *) volume->data + offset;
+
+    SINC_FMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_f(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    long offset;
+    float *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (float *) volume->data + offset;
+
+    SINC_FMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_uc(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    unsigned char *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (unsigned char *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_sc(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    char *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (char *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_us(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    unsigned short *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (unsigned short *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_ss(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    short *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (short *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_ui(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    unsigned int *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (unsigned int *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+static double 
+sinc_mac_si(Volume_Data *volume, int z, int y, int x, double *win_ptr)
+{
+    double result;
+    double value;
+    double slope = volume->scale[z];
+    double intercept = volume->offset[z];
+    long offset;
+    int *pix_ptr;
+
+    offset = (z * volume->size[ROW_AXIS] + y) * volume->size[COL_AXIS] + x;
+
+    pix_ptr = (int *) volume->data + offset;
+
+    SINC_IMAC;
+
+    return (result);
+}
+
+/* ----------------------------- MNI Header -----------------------------------
+@NAME       : windowed_sinc_interpolant
+@INPUT      : volume - pointer to volume data
+              coord - point at which volume should be interpolated in voxel 
+                 units (with 0 being first point of the volume).
+@OUTPUT     : result - interpolated value.
+@RETURNS    : TRUE if coord is within the volume, FALSE otherwise.
+@DESCRIPTION: Routine to interpolate a volume at a point with windowed
+              sinc interpolation.
+@METHOD     : 
+@GLOBALS    : 
+@CALLS      : 
+@CREATED    : July 11 2005 (Robert Vincent)
+@MODIFIED   : 
+---------------------------------------------------------------------------- */
+int
+windowed_sinc_interpolant(Volume_Data *volume, Coord_Vector coord, 
+                          double *result)
+{
+    double zt, yt, xt;
+    double zf, yf, xf;
+    int zi, yi, xi;
+    int i, j, k;
+    double new;
+    double tmp;
+    long slcmax, rowmax, colmax;
+    double zw[SINC_HALF_WIDTH_MAX * 2 + 1];
+    double yw[SINC_HALF_WIDTH_MAX * 2 + 1];
+    double xw[SINC_HALF_WIDTH_MAX * 2 + 1];
+
+    slcmax = volume->size[SLC_AXIS] - 1;
+    rowmax = volume->size[ROW_AXIS] - 1;
+    colmax = volume->size[COL_AXIS] - 1;
+
+    if ((coord[SLICE]  < 0) || (coord[SLICE]  > slcmax) ||
+        (coord[ROW]    < 0) || (coord[ROW]    > rowmax) ||
+        (coord[COLUMN] < 0) || (coord[COLUMN] > colmax)) {
+        *result = volume->fillvalue;
+        return FALSE;
+    }
+
+    zi = (int) coord[SLICE];
+    yi = (int) coord[ROW];
+    xi = (int) coord[COLUMN];
+
+    /* Check for edges - do linear interpolation at edges */
+    if ((zi > slcmax-sinc_half_width) || (zi < sinc_half_width) ||
+        (yi > rowmax-sinc_half_width) || (yi < sinc_half_width) ||
+        (xi > colmax-sinc_half_width) || (xi < sinc_half_width)) {
+        return trilinear_interpolant(volume, coord, result);
+    }
+
+    /* Calculate fractional part of the coordinate.
+     */
+    zf = coord[SLICE] - zi;
+    yf = coord[ROW] - yi;
+    xf = coord[COLUMN] - xi;
+    
+    /* Initialize the totals.
+     */
+    zt = 0.0;
+    yt = 0.0;
+    xt = 0.0;
+
+    /* Generate the three windowed sinc functions.
+     */
+    for (i = -sinc_half_width; i <= sinc_half_width; i++) {
+        tmp = windowed_sinc(zf - i);
+        zw[i + sinc_half_width] = tmp;
+        zt += tmp;
+        
+        tmp = windowed_sinc(yf - i);
+        yw[i + sinc_half_width] = tmp;
+        yt += tmp;
+        
+        tmp = windowed_sinc(xf - i);
+        xw[i + sinc_half_width] = tmp;
+        xt += tmp;
+    }
+
+    /* Now calculate the new value.
+     */
+    new = 0.0;
+    for (i = -sinc_half_width; i <= sinc_half_width; i++) {
+        for (j = -sinc_half_width; j <= sinc_half_width; j++) {
+            switch (volume->datatype) {
+            case NC_BYTE:
+                if (volume->is_signed) {
+                    tmp = sinc_mac_sc(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                else {
+                    tmp = sinc_mac_uc(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                break;
+            case NC_SHORT:
+                if (volume->is_signed) {
+                    tmp = sinc_mac_ss(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                else {
+                    tmp = sinc_mac_us(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                break;
+            case NC_INT:
+                if (volume->is_signed) {
+                    tmp = sinc_mac_si(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                else {
+                    tmp = sinc_mac_ui(volume, 
+                                      zi + i, 
+                                      yi + j, 
+                                      xi - sinc_half_width, 
+                                      xw);
+                }
+                break;
+            case NC_FLOAT:
+                tmp = sinc_mac_f(volume, 
+                                 zi + i, 
+                                 yi + j, 
+                                 xi - sinc_half_width,
+                                 xw);
+                break;
+            case NC_DOUBLE:
+                tmp = sinc_mac_d(volume,
+                                 zi + i,
+                                 yi + j,
+                                 xi - sinc_half_width,
+                                 xw);
+                break;
+
+            default:
+                fprintf(stderr, "UNHANDLED TYPE!!!\n");
+                break;
+            }
+            new += zw[i + sinc_half_width] * yw[j + sinc_half_width] * tmp;
+        }
+    }
+    *result = (new / (zt * yt * xt));
+    return TRUE;
+}
+
+
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : nearest_neighbour_interpolant
 @INPUT      : volume - pointer to volume data
@@ -817,8 +1228,8 @@ public int do_Ncubic_interpolation(Volume_Data *volume,
 @CREATED    : February 12, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int nearest_neighbour_interpolant(Volume_Data *volume, 
-                                         Coord_Vector coord, double *result)
+int nearest_neighbour_interpolant(Volume_Data *volume, 
+                                  Coord_Vector coord, double *result)
 {
    long slcind, rowind, colind, slcmax, rowmax, colmax;
 
@@ -866,7 +1277,7 @@ public int nearest_neighbour_interpolant(Volume_Data *volume,
 @CREATED    : October 29, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
+static void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
                                double slice_min[], double slice_max[])
 {
    File_Info *ofp;
@@ -899,8 +1310,8 @@ public void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
    }
 
    /* Find the max/min for each image */
-   image_maximum = MALLOC( sizeof(double) * ofp->images_per_file);
-   image_minimum = MALLOC( sizeof(double) * ofp->images_per_file);
+   image_maximum = malloc( sizeof(double) * ofp->images_per_file);
+   image_minimum = malloc( sizeof(double) * ofp->images_per_file);
    for (image=0; image < ofp->images_per_file; image++) {
       image_maximum[image] = -DBL_MAX;
       image_minimum[image] =  DBL_MAX;
@@ -996,8 +1407,8 @@ public void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
    }
 
    /* Free the image max/min arrays */
-   FREE(image_maximum);
-   FREE(image_minimum);
+   free(image_maximum);
+   free(image_minimum);
 
    return;
 }
