@@ -30,8 +30,12 @@
 #include  <unistd.h>
 #endif
 
+#ifndef CLK_TCK
+#define CLK_TCK CLOCKS_PER_SEC
+#endif
+
 #ifndef lint
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/volume_io/Prog_utils/time.c,v 1.21.2.1 2004/10/04 20:19:22 bert Exp $";
+static char rcsid[] = "$Header: /software/source/minc/volume_io/Prog_utils/time.c,v 1.21.2.3 2005/07/13 19:59:19 bert Exp $";
 #endif
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -56,7 +60,11 @@ static Real  get_clock_ticks_per_second( void )
     if( !initialized )
     {
         initialized = TRUE;
+#if HAVE_SYSCONF
+        clock_ticks_per_second = (Real) sysconf( _SC_CLK_TCK );
+#else
         clock_ticks_per_second = (Real) CLK_TCK;
+#endif
     }
 
     return( clock_ticks_per_second );
